@@ -1,7 +1,7 @@
-from django.urls import path, include
+from django.urls import include, path
 
-import fullctl.django.rest.views.usage
 import fullctl.django.rest.route.usage
+import fullctl.django.rest.views.usage
 
 urlpatterns = [
     path("", include(fullctl.django.rest.route.usage.router.urls)),
