@@ -22,10 +22,12 @@ class TwentycOAuth2(BaseOAuth2):
             raise AuthFailed(self, "User is not verified")
 
         return {
-            "username": response.get("given_name"),
+            "username": response.get("user_name"),
             "email": response.get("email") or "",
             "first_name": response.get("given_name"),
             "last_name": response.get("family_name"),
+            "is_superuser": response.get("is_superuser"),
+            "is_staff": response.get("is_staff"),
         }
 
     def user_data(self, access_token, *args, **kwargs):
