@@ -1,3 +1,4 @@
+import ipaddress
 import re
 
 from django.core.exceptions import ValidationError
@@ -41,3 +42,17 @@ def validate_alphanumeric_list(value):
 
     for item in value:
         validate_alphanumeric(item)
+
+
+def ip_address_string(value):
+    """
+    Takes an ip address string and returns a validated normalized
+    ip address string.
+
+    This will strep the net mask if it is provided
+    """
+
+    if not value:
+        return value
+    value = str(value)
+    return str(ipaddress.ip_interface(value))
